@@ -42,7 +42,7 @@ class PoolManagerServiceNoopTest(PoolManagerTestCase):
             threshold_percentage=100,
             enable_recovery_timer=False,
             enable_sync_timer=False,
-            poll_retry_interval=0.5,
+            poll_retry_interval=1,
             poll_max_retries=1,
             cache_driver='noop',
             group='service:pool_manager')
@@ -76,7 +76,7 @@ class PoolManagerServiceNoopTest(PoolManagerTestCase):
 
     def _build_zones(self, n, action, status):
         return [
-            self._build_zone("zone%02X.example" % cnt, action,
+            self._build_zone("zone%02X.example." % cnt, action,
                              status, id=generate_uuid())
             for cnt in range(n)
         ]
@@ -104,9 +104,9 @@ class PoolManagerServiceNoopTest(PoolManagerTestCase):
         self.assertEqual(2, mock_poll_for_serial_number.call_count)
         self.assertEqual(
             [call(self.admin_context, zone,
-                  self.service.pool.nameservers[0], 30, 0.5, 1, 5),
+                  self.service.pool.nameservers[0], 30, 1, 1, 5),
              call(self.admin_context, zone,
-                  self.service.pool.nameservers[1], 30, 0.5, 1, 5)],
+                  self.service.pool.nameservers[1], 30, 1, 1, 5)],
             mock_poll_for_serial_number.call_args_list)
 
         # Pool manager needs to call into mdns to calculate consensus as
@@ -199,9 +199,9 @@ class PoolManagerServiceNoopTest(PoolManagerTestCase):
         # Ensure poll_for_serial_number was called for each nameserver.
         self.assertEqual(
             [call(self.admin_context, zone,
-                  self.service.pool.nameservers[0], 30, 0.5, 1, 5),
+                  self.service.pool.nameservers[0], 30, 1, 1, 5),
              call(self.admin_context, zone,
-                  self.service.pool.nameservers[1], 30, 0.5, 1, 5)],
+                  self.service.pool.nameservers[1], 30, 1, 1, 5)],
             mock_poll_for_serial_number.call_args_list)
 
         self.assertFalse(mock_update_status.called)
